@@ -13,6 +13,55 @@ TriggerType = cloudbuild_v1.BuildTrigger
 AnyEventType = Union[cloudbuild_v1.GitHubEventsConfig, cloudbuild_v1.RepoSource]
 
 
+@dataclass
+class _SubstitutionVariable:
+    key: str
+    value: Any
+    escape_delimiter: str = None
+
+    def __post_init__(self):
+        self.escape_delimiter = '|' if ',' in str(self.value) else None
+
+    @property
+    def full_key(self) -> str:
+        # Custom substitution variables must be prefixed with an underscore
+        return f'_{self.key}'
+
+    def __str__(self) -> str:
+        # When used in a template, $_NAME should work, but it requires to be isolated by blank spaces
+        # Thus, we use ${_NAME} by default, because it allows merging with other text.
+        return '${%s}' % self.full_key
+
+    @property
+    def _escape(self):
+        # <https://cloud.google.com/run/docs/configuring/environment-variables#setting>
+        return f"^{self.escape_delimiter}^" if self.escape_delimiter else ''
+
+    def as_env_var(self, key: str = None):
+        return f'{self._escape}{key or self.key}={str(self)}'
+
+
+@dataclass
+class Substitutions:
+    _variables: Dict[str, _SubstitutionVariable] = field(default_factory=dict)
+
+    def add(self, **kwargs):
+        for k, v in kwargs.items():
+            variable = _SubstitutionVariable(key=k.upper(), value=v)
+            self._variables[variable.key] = variable
+
+    @property
+    def as_dict(self) -> Dict[str, str]:
+        return {
+            variable.full_key: str(variable.value)  # all values must be string or bytes
+            for variable in self._variables.values()
+        }
+
+    def __getattr__(self, item: str):
+        # Useful tool to ease the variable access (eg. substitution.MY_VAR_NAME)
+        return self._variables[item.upper()]
+
+
 class CloudBuild(GoogleCloudPilotAPI):
     _client_class = cloudbuild_v1.CloudBuildClient
 
@@ -23,6 +72,7 @@ class CloudBuild(GoogleCloudPilotAPI):
             args: list = None,
             env=None,
             entrypoint: str = None,
+            timeout: int = None,
     ) -> cloudbuild_v1.BuildStep:
         return cloudbuild_v1.BuildStep(
             id=identifier,
@@ -30,6 +80,7 @@ class CloudBuild(GoogleCloudPilotAPI):
             args=args,
             env=env,
             entrypoint=entrypoint,
+            timeout=self._as_duration(timeout),
         )
 
     def make_source_repo_event(
@@ -86,7 +137,8 @@ class CloudBuild(GoogleCloudPilotAPI):
             event: AnyEventType,
             tags: List[str],
             images: List[str] = None,
-            substitutions: Dict[str, str] = None,
+            substitutions: Substitutions = None,
+            timeout: int = None,
     ) -> cloudbuild_v1.BuildTrigger:
 
         def _get_event_param():
@@ -110,8 +162,9 @@ class CloudBuild(GoogleCloudPilotAPI):
             build=cloudbuild_v1.Build(
                 steps=steps,
                 images=images or [],
+                timeout=self._as_duration(timeout),
             ),
-            substitutions=substitutions,
+            substitutions=substitutions.as_dict,
             **params,
         )
 
@@ -138,7 +191,8 @@ class CloudBuild(GoogleCloudPilotAPI):
             tags: List[str] = None,
             project_id: str = None,
             images: List[str] = None,
-            substitutions: Dict[str, str] = None,
+            substitutions: Substitutions = None,
+            timeout: int = None,
     ) -> TriggerType:
         trigger = self._make_trigger(
             name=name,
@@ -148,6 +202,7 @@ class CloudBuild(GoogleCloudPilotAPI):
             tags=tags,
             images=images,
             substitutions=substitutions,
+            timeout=timeout,
         )
 
         response = self.client.create_build_trigger(
@@ -164,8 +219,9 @@ class CloudBuild(GoogleCloudPilotAPI):
             steps: List[cloudbuild_v1.BuildStep],
             tags: List[str] = None,
             images: List[str] = None,
-            substitutions: Dict[str, str] = None,
+            substitutions: Substitutions = None,
             project_id: str = None,
+            timeout: int = None,
     ) -> TriggerType:
         trigger = self._make_trigger(
             name=name,
@@ -175,6 +231,7 @@ class CloudBuild(GoogleCloudPilotAPI):
             tags=tags,
             images=images,
             substitutions=substitutions,
+            timeout=timeout,
         )
 
         response = self.client.update_build_trigger(
@@ -193,7 +250,8 @@ class CloudBuild(GoogleCloudPilotAPI):
             tags: List[str] = None,
             project_id: str = None,
             images: List[str] = None,
-            substitutions: Dict[str, str] = None,
+            substitutions: Substitutions = None,
+            timeout: int = None,
     ) -> TriggerType:
         create_args = dict(
             name=name,
@@ -204,6 +262,7 @@ class CloudBuild(GoogleCloudPilotAPI):
             project_id=project_id,
             images=images,
             substitutions=substitutions,
+            timeout=timeout,
         )
 
         try:
@@ -211,6 +270,31 @@ class CloudBuild(GoogleCloudPilotAPI):
         except AlreadyExists:
             return await self.update_trigger(**create_args)
 
+    async def run_trigger(
+            self,
+            name: str,
+            tag_name: str = None,
+            branch_name: str = None,
+            commit_sha: str = None,
+            project_id: str = None,
+    ) -> TriggerType:
+        params = [tag_name, branch_name, commit_sha]
+        if len([x for x in params if x]) != 1:
+            raise exceptions.ValidationError("Only one of {tag_name, branch_name, commit_sha} must be provided")
+
+        event = cloudbuild_v1.RepoSource(
+            project_id=project_id or self.project_id,
+            tag_name=tag_name,
+            branch_name=branch_name,
+            commit_sha=commit_sha,
+        )
+        response = self.client.run_build_trigger(
+            trigger_id=name,
+            source=event,
+            project_id=project_id or self.project_id,
+        )
+        return response
+
     def get_builds(
             self,
             trigger_id: str = None,
@@ -257,42 +341,7 @@ class CloudBuild(GoogleCloudPilotAPI):
         )
 
 
-@dataclass
-class _SubstitutionVariable:
-    key: str
-    value: Any
-
-    @property
-    def as_kv(self) -> str:
-        return '%s=%s' % (self.key, str(self))
-
-    @property
-    def custom_key(self) -> str:
-        # Custom substitution variables must be prefixed with an underscore
-        return f'_{self.key}'
-
-    def __str__(self) -> str:
-        # When used in a template, $_NAME should work, but it requires to be isolated by blank spaces
-        # Thus, we use ${_NAME} by default, because it allows merging with other text.
-        return '${%s}' % self.custom_key
-
-
-@dataclass
-class SubstitutionHelper:
-    _variables: Dict[str, _SubstitutionVariable] = field(default_factory=dict)
-
-    def add(self, **kwargs):
-        for k, v in kwargs.items():
-            variable = _SubstitutionVariable(key=k.upper(), value=v)
-            self._variables[variable.key] = variable
-
-    @property
-    def as_dict(self) -> Dict[str, str]:
-        return {
-            variable.custom_key: str(variable.value)  # all values must be string or bytes
-            for variable in self._variables.values()
-        }
-
-    def __getattr__(self, item: str):
-        # Useful tool to ease the variable access (eg. substitution.MY_VAR_NAME)
-        return self._variables[item.upper()]
+__all__ = (
+    'CloudBuild',
+    'Substitutions',
+)
