@@ -9,6 +9,9 @@ from gcp_pilot.base import GoogleCloudPilotAPI
 class CloudLogging(GoogleCloudPilotAPI):
     _client_class = logging.Client
 
+    def _get_client_extra_kwargs(self):
+        return {'project': self.project_id}
+
     def enable(self, log_level=INFO):
         self.client.setup_logging(log_level=log_level)
 
